@@ -523,7 +523,7 @@ class ESP_ATcontrol:
             response = b""
             while (time.monotonic() - stamp) < timeout:
                 if self._uart.in_waiting:
-                    response += self._uart.read(1)
+                    response += self._uart.read(self._uart.in_waiting)
                     self.hw_flow(False)
                     if response[-4:] == b"OK\r\n":
                         break
